/*
This do-file replicates the tables in the Technical Note, 'Identifying foreign firms and South African multinational enterprises'
Author: Michael Kilumelume (kilumelume.michael@gmail.com) 
last updated: 2020.11.19

*/
********************************************************************************
*globals 
********************************************************************************
*create save directory
cap mkdir 	" "
*data directory
gl dadrs = "Z:\Master Data\CIT-IRP5 Panel"
*save directory
gl sadrs = " "
gl yearlist = " "
********************************************************************************
*Change directory: The document with the tables will be saved in the directory below 
******************************************************************************** 
cd "$sadrs"
********************************************************************************
*The tables are created version 4 of the CIT panel 
********************************************************************************
use "$dadrs\citirp5_v4", clear 
*open .docx document in memory 
putdocx clear 
putdocx begin
putdocx paragraph, font(Segoe UI, 22) halign(justify)
putdocx text ("Identifying foreign firms and South African multinational enterprises"), bold
putdocx paragraph, font(Segoe UI, 16) halign(justify) 
putdocx text ("Michael Kilumelume, Hayley Reynolds, and Amina Ebrahim") 

putdocx pagebreak
********************************************************************************
*Tables 4-9 
********************************************************************************
putdocx paragraph, font(Segoe UI, 16) halign(center)
putdocx text ("Tables 4-9") , bold
*table 4: Strict foreign firm indicator
putdocx table tbl4=(1,5) , border(all,nil) halign(center) 
putdocx table tbl4(1,1) = ("") , border(top) border(bottom) border(left) 
putdocx table tbl4(1,2) =  (" "), border(top) border(bottom) font(Garamond, 9) halign(center)
putdocx table tbl4(1,3) =  ("Ultimately foreign Controlled?"), border(top) border(bottom)colspan(2)  font(Garamond, 9) halign(center) border(left) border(right)
putdocx table tbl4(1,4) =  (" "), border(top) border(bottom)  font(Garamond, 9) halign(center) border(right)
putdocx table tbl4(1,.) , addrows(1)
putdocx table tbl4(2,1) = ("tax year ") , colspan(1)  border(bottom) border(top) border(left) font(Garamond, 9)
putdocx table tbl4(2,2) = ("All firms"), border(top) border(bottom) font(Garamond, 9) halign(center)
putdocx table tbl4(2,3) = ("No") , halign(center)  border(bottom) border(right)  border(left) font(Garamond, 9)
putdocx table tbl4(2,4) = ("Yes") , halign(center) font(Garamond, 9) border(bottom) border(top) border(right)
putdocx table tbl4(2,5) = ("ITR14_c_foreign_strict"), border(top) border(bottom)  font(Garamond, 9) halign(center) border(right)
putdocx table tbl4(2,.) , addrows(12)  
set trace off
local a =3 
foreach year in $yearlist {
local row=`a'
count if taxrefno!= "" & taxyear==`year'
local all_firms = r(N)
tab ITR14_c_fgnhold
sum ITR14_c_fgnhold if ITR14_c_fgnhold==0 & taxyear==`year'
local no=r(N)
sum ITR14_c_fgnhold if ITR14_c_fgnhold==1 & taxyear==`year'
local yes=r(N)
putdocx table tbl4(`row', 1) = ("`year'"), font(Garamond, 9) halign(center) border(left)
putdocx table tbl4(`row', 2) = ("`all_firms'") , font(Garamond, 9) halign(center) nformat(%12.0gc) 
putdocx table tbl4(`row', 3) = ("`no'"), font(Garamond, 9) halign(center) nformat(%12.0gc) 
putdocx table tbl4(`row', 4) = ("`yes'") , font(Garamond, 9) halign(center) nformat(%12.0gc) 
putdocx table tbl4(`row', 5) = ("`yes'") , font(Garamond, 9) halign(center) border(right) nformat(%12.0gc)
local a = `row'+1
}
putdocx table tbl4(13,.) , border(bottom)
putdocx table tbl4(14,.) , addrows(2)
putdocx table tbl4(15,1) = ("Notes: Tax year 2018 is not fully populated due to delays in tax reporting; this results in the lower numbers in 2018 in this version of the panel. Number would likely be revised upward in future version of the panel") , font(Garamond, 9) colspan(5)  
putdocx table tbl4(16,1) = ("Source: CIT-IRP5 panel v4.0 (National Treasury and UNU-WIDER 2020") , font(Garamond, 9) colspan(5)  
putdocx table tbl4(1,.) , addrows(1, before)
putdocx table tbl4(1,1 ) = ("Table 4: Strict foreign firm indicator") , font(Garamond, 9) colspan(5)  border(bottom)
putdocx sectionbreak, landscape 

*Table 5: Broad foreign firm indicator
putdocx table tbl5=(1,9) , border(all,nil) halign(center) 
putdocx table tbl5(1,1) = (" ") , border(top) border(bottom) border(left)
putdocx table tbl5(1,2) =  (""), border(top) border(bottom) font(Garamond, 9) halign(center)
putdocx table tbl5(1,3) =  ("Non Residency"), border(top) border(bottom)colspan(3)  font(Garamond, 9) halign(center) border(left) border(right)
putdocx table tbl5(1,4) =  (""), border(top) border(bottom)  font(Garamond, 9) halign(center)
putdocx table tbl5(1,5) =  (""), border(top) border(bottom)  font(Garamond, 9) halign(center)
putdocx table tbl5(1,6) =  (""), border(top) border(bottom)  font(Garamond, 9) halign(center)
putdocx table tbl5(1,7) =  (""), border(top) border(bottom)  font(Garamond, 9) halign(center) border(right)
putdocx table tbl5(1,.) , addrows(1)
putdocx table tbl5(2,1) = ("tax year ") , colspan(1)  border(bottom) border(top) font(Garamond, 9) border(left) border(right)
putdocx table tbl5(2,2) = ("All firms"), border(top) border(bottom) font(Garamond, 9) border(right)
putdocx table tbl5(2,3) = ("Not resident in SA for income tax purposes") , halign(left)  border(bottom) border(right)  border(left) font(Garamond, 7)
putdocx table tbl5(2,4) = ("Due to foreign incoporation") , halign(left)  border(bottom) border(right)  border(left) font(Garamond, 7) 
putdocx table tbl5(2,5) = ("Due to treaty to avoid double taxation") , halign(left) font(Garamond, 7) border(bottom) border(top) border(right)
putdocx table tbl5(2,6) = ("subsidiary"), border(top) border(bottom)  font(Garamond, 9) halign(center) border(right)
putdocx table tbl5(2,7) = ("Dividends subject to Double Taxation relief"), border(top) border(bottom)  font(Garamond, 9) halign(center) border(right)
putdocx table tbl5(2,8) = ("Branch"), border(top) border(bottom)  font(Garamond, 9) halign(center) border(right)
putdocx table tbl5(2,9) = ("ITR14_c_foreign_broad"), border(top) border(bottom)  font(Garamond, 9) halign(center) border(right)
putdocx table tbl5(2,.) , addrows(12)  
set trace off
local a =3 
foreach year in $yearlist{
local row=`a'
count if taxrefno!= "" & taxyear==`year'
local all_firms = r(N)
sum  ITR14_c_sarestax if ITR14_c_sarestax==0 & taxyear==`year'
local sarestax=r(N)
sum  ITR14_c_foreignincorp if ITR14_c_foreignincorp==1 & taxyear==`year'
local foreigncorp=r(N)
sum  ITR14_c_foreignincorpddt if ITR14_c_foreignincorpddt ==1  & taxyear==`year'
local doubletaxation=r(N)
sum ITR14_c_fgnhold if ITR14_c_fgnhold==1 & taxyear==`year'
local subsidiary=r(N) 
sum c_divdtr  if c_divdtr >0 & c_divdtr<. & taxyear==`year'
local c_divdtr=r(N) 
sum ITR14_c_fgnbranch if ITR14_c_fgnbranch==1 & taxyear == `year'
local branch=r(N) 
cap drop ITR14_c_foreign_broad
gen ITR14_c_foreign_broad=1 if taxyear==`year' & (ITR14_c_sarestax==0 | ITR14_c_foreignincorp==1 | ITR14_c_foreignincorpddt==1 | ITR14_c_fgnhold==1 | ITR14_c_fgnbranch==1|c_divdtr >0 & c_divdtr<. )
sum ITR14_c_foreign_broad
local broad=r(N)
putdocx table tbl5(`row', 1) = ("`year'"), font(Garamond, 9) halign(center) border(left)
putdocx table tbl5(`row', 2) = ("`all_firms'") , font(Garamond, 9) halign(center) nformat(%12.0gc) 
putdocx table tbl5(`row', 3) = ("`sarestax'"), font(Garamond, 9) halign(center) nformat(%12.0gc)
putdocx table tbl5(`row', 4) = ("`foreigncorp'"), font(Garamond, 9) halign(center) nformat(%12.0gc)
putdocx table tbl5(`row', 5) = ("`doubletaxation'") , font(Garamond, 9) halign(center) nformat(%12.0gc) 
putdocx table tbl5(`row', 6) = ("`subsidiary'") , font(Garamond, 9) halign(center) nformat(%12.0gc) 
putdocx table tbl5(`row', 7) = ("`c_divdtr'") , font(Garamond, 9) halign(center) nformat(%12.0gc) 
putdocx table tbl5(`row', 8) = ("`branch'") , font(Garamond, 9) halign(center) nformat(%12.0gc) 
putdocx table tbl5(`row', 9) = ("`broad'") , font(Garamond, 9) halign(center) border(right) nformat(%12.0gc) 
local a = `row'+1
}
putdocx table tbl5(13,.) , border(bottom) 
putdocx table tbl5(14,.) , addrows(2)  
putdocx table tbl5(15,1) = ("Notes: Tax year 2018 is not fully populated due to delays in tax reporting; this results in the lower numbers in 2018 in this version of the panel. Number would likely be revised upward in future version of the panel") , font(Garamond, 9) colspan(8)  
putdocx table tbl5(16,1) = ("Source: CIT-IRP5 panel v4.0 (National Treasury and UNU-WIDER 2020).") , font(Garamond, 9) colspan(8)
putdocx table tbl5(1,.) , addrows(1, before)
putdocx table tbl5(1,1 ) = ("Table 5: Broad foreign firm indicator") , font(Garamond, 9) colspan(5)  border(bottom)
putdocx sectionbreak, landscape 

*Table 6: Local-held and foreign held groups
putdocx table tbl6=(1,6) , border(all,nil) halign(center) 
putdocx table tbl6(1,1) = (" ") , border(top) border(bottom)  border(left)
putdocx table tbl6(1,2) =  (""), border(top) border(bottom) font(Garamond, 9) halign(center)
putdocx table tbl6(1,3) =  ("Ultimate holding company outside SA?"), border(top) border(left) border(right)border(bottom)  font(Garamond, 9)colspan(2) halign(center)
putdocx table tbl6(1,4) =  (""), border(top) border(bottom)  font(Garamond, 9) halign(center)
putdocx table tbl6(1,5) =  (" "), border(top) border(bottom)  font(Garamond, 9) halign(center) border(right)
putdocx table tbl6(1,.) , addrows(1)
putdocx table tbl6(2,1) = ("tax year") , colspan(1)  border(bottom) border(right) border(top)  border(left) font(Garamond, 9) halign(center)
putdocx table tbl6(2,2) = ("All firms"), border(top) border(bottom) font(Garamond, 9) halign(center)
putdocx table tbl6(2,3) = ("No") , halign(center)  font(Garamond, 9) border(bottom) border(top) border(right)
putdocx table tbl6(2,4) = ("Yes") , halign(center)   font(Garamond, 9) border(bottom) border(top) border(right)
putdocx table tbl6(2,5) = ("Local-held group ") , halign(center)  border(bottom) border(top) border(right) font(Garamond, 9)
putdocx table tbl6(2,6) = ("(Ultimately) Foreign-held") , halign(center) border(right) border(bottom) border(top) font(Garamond, 9)
putdocx table tbl6(2,.) , addrows(12)  
set trace off
local a =3 
foreach year in $yearlist {
local row=`a'
count if taxrefno!= "" & taxyear==`year'
local all_firms = r(N)
sum ITR14_c_fgnhold if ITR14_c_fgnhold==0 & taxyear==`year'
local ultimate_no=r(N)
sum ITR14_c_fgnhold if ITR14_c_fgnhold==1 & taxyear==`year'
local ultimate_yes=r(N)
cap drop local_held_group
gen  local_held_group = 1 if  taxyear==`year' & ITR14_c_fgnhold==0 
sum local_held_group
local lheld=r(N)
cap drop foreign_held_group
gen  foreign_held_group = 1 if  taxyear==`year' &  ITR14_c_fgnhold==1 
sum foreign_held_group
local fheld=r(N)
putdocx table tbl6(`row', 1) = ("`year'"), font(Garamond, 9) halign(center) border(left) 
putdocx table tbl6(`row', 2) = ("`all_firms'") , font(Garamond, 9) halign(center)  nformat(%12.0gc) 
putdocx table tbl6(`row', 3) = ("`ultimate_no'") , font(Garamond, 9) halign(center) nformat(%12.0gc) 
putdocx table tbl6(`row', 4) = ("`ultimate_yes'") , font(Garamond, 9) halign(center) nformat(%12.0gc) 
putdocx table tbl6(`row', 5) = ("`lheld'") , font(Garamond, 9) halign(center) nformat(%12.0gc) 
putdocx table tbl6(`row', 6) = ("`fheld'") , font(Garamond, 9) halign(center) border(right) nformat(%12.0gc) 
local a = `row'+1
}
putdocx table tbl6(13,.) , border(bottom)  
putdocx table tbl6(14,.) , addrows(2)  
putdocx table tbl6(15,1) = ("Notes: Tax year 2018 is not fully populated due to delays in tax reporting; this results in the lower numbers in 2018 in this version of the panel. Number would likely be revised upward in future version of the panel") , font(Garamond, 9) colspan(10)  
putdocx table tbl6(16,1) = ("Source: CIT-IRP5 panel v4.0 (National Treasury and UNU-WIDER 2020).") , font(Garamond, 9) colspan(10) 
putdocx table tbl6(1,.) , addrows(1, before)
putdocx table tbl6(1,1 ) = ("Table 6: local-held and foreign held groups") , font(Garamond, 9) colspan(10)  border(bottom)
putdocx pagebreak 

*Table 7: South African parents of MNEs

putdocx table tbl7=(2,7) , border(all,nil) halign(center) 
putdocx table tbl7(1,1) = (" ") , border(top) border(left) 
putdocx table tbl7(1,2) =  (""), border(top)  border(right) border(bottom) 
putdocx table tbl7(1,3) =  ("Foreign Connected"), border(top) border(right) border(bottom)colspan(4)  font(Garamond, 9) halign(center)
putdocx table tbl7(1,4) =  (""), border(top)  border(bottom) font(Garamond, 9) halign(center) border(right)
putdocx table tbl7(2,1) = ("tax year") ,  border(left) border(top) colspan(1) border(right) border(bottom) font(Garamond, 9) halign(center)
putdocx table tbl7(2,2) = ("local-held group"), border(bottom) font(Garamond, 9) halign(center)
putdocx table tbl7(2,3) = ("Part of an MNE ") , halign(left)  border(bottom) border(right)  border(left) font(Garamond, 9)
putdocx table tbl7(2,4) = ("CFC ownership") , halign(left) font(Garamond, 9) border(bottom) border(top) border(right)
putdocx table tbl7(2,5) = ("participation exemption") , halign(left) font(Garamond, 9) border(bottom) border(top) border(right)
putdocx table tbl7(2,6) = ("dividend exempted from taxation") , halign(left) font(Garamond, 9) border(bottom) border(top) border(right)
putdocx table tbl7(2,7) = ("SA parent of MNE") , halign(center) border(bottom) border(right) font(Garamond, 9)
putdocx table tbl7(2,.) , addrows(12)  
set trace off
local a =3 
cap drop local_held_group
gen  local_held_group = 1 if  ITR14_c_fgnhold==0
foreach year in $yearlist {
local row=`a'
count if taxrefno!= "" & taxyear==`year' &  local_held_group == 1
local lheld=r(N) 
sum ITR14_c_mne if ITR14_c_mne==1 & taxyear==`year' &  local_held_group ==1
local mne=r(N) 
sum c_cfcownership if c_cfcownership==1 & taxyear==`year' &  local_held_group ==1 
local cfc=r(N) 
sum ITR14_c_fdivpexmpt if ITR14_c_fdivpexmpt==1 & taxyear==`year' &  local_held_group ==1 
local fdipexempt=r(N) 
sum ITR14_c_fdivexmpt  if ITR14_c_fdivexmpt==1 & taxyear==`year'
local dvdexpt=r(N) 
cap drop sa_parent 
gen sa_parent=1 if (taxyear==`year' &  local_held_group ==1 & c_cfcownership==1) |( taxyear==`year' &  local_held_group ==1 & ITR14_c_mne==1 )| ( ITR14_c_fdivpexmpt==1 & taxyear==`year' & local_held_group ==1) | ( taxyear==`year' &  local_held_group ==1 & ITR14_c_fdivexmpt==1 )
sum sa_parent
local sap=r(N)
putdocx table tbl7(`row', 1) = ("`year'"), font(Garamond, 9) halign(center) border(left) 
putdocx table tbl7(`row', 2) = ("`lheld'") , font(Garamond, 9) halign(center) nformat(%12.0gc)
putdocx table tbl7(`row', 3) = ("`mne'"), font(Garamond, 9) halign(center) nformat(%12.0gc) 
putdocx table tbl7(`row', 4) = ("`cfc'") , font(Garamond, 9) halign(center) nformat(%12.0gc) 
putdocx table tbl7(`row', 5) = ("`fdipexempt'") , font(Garamond, 9) halign(center) nformat(%12.0gc) 
putdocx table tbl7(`row', 6) = ("`dvdexpt'") , font(Garamond, 9) halign(center) nformat(%12.0gc)
putdocx table tbl7(`row', 7) = (" `sap'") , font(Garamond, 9) halign(center) border(right) nformat(%12.0gc)
local a = `row'+1
}
putdocx table tbl7(13,.) , border(bottom)
putdocx table tbl7(14,.) , addrows(2)   
putdocx table tbl7(15,1) = ("Notes: There are other exemptions, besides the participation exemption, available for foreign dividends. Where there are less than 10 firms in a category the number is ‘masked‘ for data security reasons. Tax year 2018 is not fully populated due to delays in tax reporting; this results in the lower numbers in 2018 in this version of the panel. Number would likely be revised upward in future version of the panel.") , font(Garamond, 9) colspan(8)   
putdocx table tbl7(16,1) = ("Source: CIT-IRP5 panel v4.0 (National Treasury and UNU-WIDER 2020).") , font(Garamond, 9) colspan(8)  
putdocx table tbl7(1,.) , addrows(1, before)
putdocx table tbl7(1,1 ) = ("Table 7: South African parents of MNEs") , font(Garamond, 9) colspan(8)  border(bottom)
putdocx pagebreak

*Table 8: MNE Type indicator

putdocx table tbl8=(1,4) , border(all,nil) halign(center) 
putdocx table tbl8(1,1) = ("") , border(top) border(bottom) border(left)
putdocx table tbl8(1,2) =  (""), border(top) border(bottom) font(Garamond, 9) halign(center)
putdocx table tbl8(1,3) =  ("ITR14_c_mne_type"), border(top) border(bottom)colspan(2)border(right)  border(left)  font(Garamond, 9) halign(center)
putdocx table tbl8(1,.) , addrows(1)
putdocx table tbl8(2,1) = (" tax year ") , colspan(1)  border(left) border(right) border(bottom) border(top)font(Garamond, 9) halign(center)
putdocx table tbl8(2,2) = ("All firms") , colspan(1)  border(bottom) border(top) font(Garamond, 9) halign(center)
putdocx table tbl8(2,3) = ("SA parent") , halign(center)  border(bottom) border(right)  border(left) font(Garamond, 9)
putdocx table tbl8(2,4) = ("Foreign parent") , halign(center) font(Garamond, 9) border(bottom) border(top) border(right)
putdocx table tbl8(2,.) , addrows(12)  
set trace off
local a =3 
cap drop local_held_group
gen  local_held_group = 1 if (ITR14_c_partofgroupfinstmnts==1 & ITR14_c_fgnhold==0 )
cap drop sa_parent 
gen sa_parent=1 if  ( local_held_group ==1 & c_cfcownership==1) |(local_held_group ==1 & ITR14_c_mne==1 )| ( ITR14_c_fdivpexmpt==1  & local_held_group ==1) 
cap drop foreign_held_group
gen  foreign_held_group = 1 if  (ITR14_c_partofgroupfinstmnts==1 & ITR14_c_fgnhold==1 )
foreach year in $yearlist {
local row=`a'
count if taxrefno!= "" & taxyear==`year'
local all_firms = r(N)
sum  sa_parent if  sa_parent==1 & taxyear==`year'
local sap = r(N)
sum foreign_held_group if foreign_held_group==1 & taxyear==`year'
local fp=r(N)
putdocx table tbl8(`row', 1) = ("`year'"), font(Garamond, 9) halign(center) border(left)
putdocx table tbl8(`row', 2) = ("`all_firms'") , font(Garamond, 9) halign(center) nformat(%12.0gc) 
putdocx table tbl8(`row', 3) = ("`sap'"), font(Garamond, 9) halign(center) nformat(%12.0gc) 
putdocx table tbl8(`row', 4) = ("`fp'") , font(Garamond, 9) halign(center) border(right) nformat(%12.0gc) 
local a = `row'+1
}
putdocx table tbl8(13,.) , border(bottom)
putdocx table tbl8(14,.) , addrows(2)  
putdocx table tbl8(15,1) = ("Notes: Where there are less than 10 firms in a category the number is ‘masked‘ for data security reasons. Tax year 2018 is not fully populated due to delays in tax reporting; this results in the lower numbers in 2018 in this version of the panel. Number would likely be revised upward in future version of the panel") , font(Garamond, 9) colspan(7) 
putdocx table tbl8(16,1) = ("Source: CIT-IRP5 panel v4.0 (National Treasury and UNU-WIDER 2020).") , font(Garamond, 9) colspan(7) 
putdocx table tbl8(1,.) , addrows(1, before)
putdocx table tbl8(1,1 ) = ("Table 8: MNE Type indicator") , font(Garamond, 9) colspan(7)  border(bottom)
putdocx pagebreak

*Table 9: SA foreign-connected firms 

putdocx table tbl9=(2,9) , border(all,nil) halign(center) 
putdocx table tbl9(1,1) = (" ") , border(top) border(left) 
putdocx table tbl9(1,2) =  (""), border(top)  border(right) border(bottom) 
putdocx table tbl9(1,3) =  ("Foreign Connected"), border(top) border(right) border(bottom) colspan(6)  font(Garamond, 9) halign(center)
putdocx table tbl9(1,4) =  (""), border(top)  border(bottom) font(Garamond, 9) halign(center) border(right)
putdocx table tbl9(2,1) = ("tax year") ,  border(left) border(top) colspan(1) border(right) border(bottom) font(Garamond, 9) halign(center)
putdocx table tbl9(2,2) = ("All firms"), border(bottom) font(Garamond, 9) halign(center)
putdocx table tbl9(2,3) = ("Head quarter company with minimal asset rules"), border(bottom) font(Garamond, 9) halign(center)
putdocx table tbl9(2,4) = ("Foreign controlled company ") , halign(left)  border(bottom) border(right)  border(left) font(Garamond, 9)
putdocx table tbl9(2,5) = ("dividend exempted from taxation") , halign(left) font(Garamond, 9) border(bottom) border(top) border(right)
putdocx table tbl9(2,6) = ("participation exemption") , halign(left) font(Garamond, 9) border(bottom) border(top) border(right)
putdocx table tbl9(2,7) = ("Foreign Income s13(1)(a)") , halign(center) border(right) border(bottom) border(top) font(Garamond, 9)
putdocx table tbl9(2,8) = ("Foreign Expenditure s13(1)(a)") , halign(center)  border(right) border(bottom) border(top) font(Garamond, 9)
putdocx table tbl9(2,9) = ("SA Foreign Connected firms ") , halign(center) border(bottom) border(right) font(Garamond, 9)
putdocx table tbl9(2,.) , addrows(12)  
set trace off
local a =3 
cap drop local_held_group
gen  local_held_group = 1 if (ITR14_c_partofgroupfinstmnts==1 & ITR14_c_fgnhold==0 )
foreach year in $yearlist {
local row=`a'
count if taxrefno!= "" & taxyear==`year' 
local all=r(N) 
sum ITR14_c_hqrtrasset if ITR14_c_hqrtrasset==1 & taxyear==`year' 
local hqr=r(N) 
sum c_cfcownership if c_cfcownership==1 & taxyear==`year' 
local cfc=r(N) 
sum ITR14_c_fdivexmpt  if ITR14_c_fdivexmpt==1 & taxyear==`year'
local associate=r(N) 
sum ITR14_c_fdivpexmpt if ITR14_c_fdivpexmpt==1 & taxyear==`year' 
local fdipexempt=r(N) 
sum ITR14_c_fgninc31_1a  if ITR14_c_fgninc31_1a > 0 & ITR14_c_fgninc31_1a <. & taxyear==`year'    
local finc=r(N)
sum ITR14_c_fgnexp31_1a  if ITR14_c_fgnexp31_1a > 0 & ITR14_c_fgnexp31_1a <.  & taxyear==`year'  
local fex=r(N)
cap drop sa_fcf 
gen sa_fcf=1 if (ITR14_c_hqrtrasset==1 & taxyear==`year') | (c_cfcownership==1 & taxyear==`year' ) | (ITR14_c_fdivexmpt==1 & taxyear==`year') | (ITR14_c_fdivpexmpt==1 & taxyear==`year') | (ITR14_c_fgninc31_1a > 0 & ITR14_c_fgninc31_1a <. & taxyear==`year') | (ITR14_c_fgnexp31_1a > 0 & ITR14_c_fgnexp31_1a <.  & taxyear==`year')
sum sa_fcf
local safcf=r(N)
putdocx table tbl9(`row', 1) = ("`year'"), font(Garamond, 9) halign(center) border(left) nformat(%12.0gc) 
putdocx table tbl9(`row', 2) = ("`all'") , font(Garamond, 9) halign(center) nformat(%12.0gc) 
putdocx table tbl9(`row', 3) = ("`hqr'"), font(Garamond, 9) halign(center) nformat(%12.0gc)
putdocx table tbl9(`row', 4) = ("`cfc'") , font(Garamond, 9) halign(center) nformat(%12.0gc) 
putdocx table tbl9(`row', 5) = ("`associate'") , font(Garamond, 9) halign(center) nformat(%12.0gc) 
putdocx table tbl9(`row', 6) = ("`fdipexempt'") , font(Garamond, 9) halign(center) nformat(%12.0gc)
putdocx table tbl9(`row', 7) = ("`finc'") , font(Garamond, 9) halign(center) nformat(%12.0gc) 
putdocx table tbl9(`row', 8) = (" `fex'") , font(Garamond, 9) halign(center) nformat(%12.0gc)
putdocx table tbl9(`row', 9) = (" `safcf'") , font(Garamond, 9) halign(center) border(right) nformat(%12.0gc) 
local a = `row'+1
}
putdocx table tbl9(13,.) , border(bottom)
putdocx table tbl9(14,.) , addrows(2)   
putdocx table tbl9(15,1) = ("Notes: Where there are less than 10 firms in a category the number is ‘masked‘ for data security reasons.Tax year 2018 is not fully populated due to delays in tax reporting; this results in the lower numbers in 2018 in this version of the panel. Number would likely be revised upward in future version of the panel") , font(Garamond, 9) colspan(8) 
putdocx table tbl9(16,1) = ("Source: CIT-IRP5 panel v4.0 (National Treasury and UNU-WIDER 2020).") , font(Garamond, 9) colspan(8)   
putdocx table tbl9(1,.) , addrows(1, before)
putdocx table tbl9(1,1 ) = ("Table 9: SA foreign-connected firms") , font(Garamond, 9) colspan(8)  border(bottom)

putdocx pagebreak
 
 *******************************************************************************
 * Appendix C: Foreign firms and MNE type by company type classification
 *******************************************************************************
use "$dadrs\citirp5_v4", clear 
putdocx paragraph, font(Segoe UI, 16) halign(center)
putdocx text ("Appendix C: Foreign firms and MNE type by company type classification") , bold
*Table C1: Foreign firms by company type
putdocx table tbl10 = (1,5) , border(all, nil) halign(center)
putdocx table tbl10(1,1) = (" ") , border(left) border(right) border(top) border(bottom) colspan(2)
putdocx table tbl10(1,2) = ("Company type"), font(Arial, 8)  border(left) border(right) border(top) border(bottom) colspan(3) halign(center)
putdocx table tbl10(1,.), addrows(1)
putdocx table tbl10(2,1) = ("Tax year"), font(Arial, 8)  border(top) border(bottom) halign(center) border(left)
putdocx table tbl10(2,2) = (" "), font(Arial, 8)  border(top) border(bottom) halign(center)
putdocx table tbl10(2,3) = ("Micro"),  font(Arial, 8)  border(left) border(right) border(top) border(bottom) halign(center)
putdocx table tbl10(2,4) = ("Small"), font(Arial, 8)  border(left) border(right) border(top) border(bottom) halign(center)
putdocx table tbl10(2,5) = ("Medium -large"), font(Arial, 8)  border(left) border(right) border(top) border(bottom) halign(center) 
local row = 2
foreach year in $yearlist{
	putdocx table tbl10(`row',.) , addrows(2)
	local ++row 
	putdocx table tbl10(`row', 1) = ("`year'") , border(left) border(top)  border(right) halign(center) font(Arial, 8)
	local ++row
	putdocx table tbl10(`row', 1) = (" ") , border(left) border(bottom) border(right)
    local --row 
	putdocx table tbl10(`row', 2) = ("Broad") , border(left) border(top) border(bottom) border(right) font(Arial, 8)
	local ++row
	putdocx table tbl10(`row', 2) = ("Strict") , border(left) border(top) border(bottom) border(right) font(Arial, 8)
	
	*Table values 
	count if ITR14_c_foreign_broad == 1 & c_type ==3 & taxyear ==`year' 
	local b_m = r(N)
	count if ITR14_c_foreign_broad == 1 & c_type ==4 & taxyear ==`year' 
	local b_s = r(N)
	count if ITR14_c_foreign_broad == 1 & c_type ==5 & taxyear ==`year' 
	local b_ml = r(N)
	count if ITR14_c_foreign_strict == 1 & c_type ==3 & taxyear ==`year' 
	local s_m = r(N)
	count if ITR14_c_foreign_strict == 1 & c_type ==4 & taxyear ==`year' 
	local s_s = r(N)
	count if ITR14_c_foreign_strict == 1 & c_type ==5 & taxyear ==`year' 
	local s_ml = r(N)
	
	local --row 
	putdocx table tbl10(`row',3) = ("`b_m'") , font(Arial, 8) halign(center) nformat(%12.0gc) 
	putdocx table tbl10(`row',4) = ("`b_s'") , font(Arial, 8) halign(center) nformat(%12.0gc) 
	putdocx table tbl10(`row',5) = ("`b_ml'") , font(Arial, 8) halign(center) border(right) nformat(%12.0gc) 
	
	local ++row 
	putdocx table tbl10(`row',3) = ("`s_m'") , font(Arial, 8) halign(center) nformat(%12.0gc) 
	putdocx table tbl10(`row',4) = ("`s_s'") , font(Arial, 8) halign(center) nformat(%12.0gc) 
	putdocx table tbl10(`row',5) = ("`s_ml'") , font(Arial, 8) halign(center) border(right) nformat(%12.0gc) 
	
	
}

putdocx table tbl10(`row', .) , addrows(2)
local ++row 
putdocx table tbl10(`row', 1) = ("Notes: The company type classification is based on the gross income and total assets amounts reported by firms Where there are less than 10 firms in a category the number is ‘masked‘ for data security reasons. Tax year 2018 is not fully populated due to delays in tax reporting; this results in the lower numbers in 2018 in this version of the panel. Number would likely be revised upward in future version of the panel") ,  font(Arial, 8) colspan(5) border(top) 
local ++row 
putdocx table tbl10(`row', 1) = ("Source: Authors’ illustration of the data in the CIT-IRP5 panel v4.0 (National Treasury and UNU-WIDER 2020).") , font(Arial, 8) 
putdocx table tbl10(1,. ) , addrows(1, before) 
putdocx table tbl10(1, 1) = ("Table C1: Foreign firms by company type") ,  font(Arial, 8) colspan(5) 

putdocx pagebreak
*Table C2: MNEs by Company type
putdocx table tbl11 = (1,5) , border(all, nil) halign(center)
putdocx table tbl11(1,1) = (" ") , border(left) border(right) border(top) border(bottom) colspan(2)
putdocx table tbl11(1,2) = ("Company type"), font(Arial, 8)  border(left) border(right) border(top) border(bottom) colspan(3) halign(center)
putdocx table tbl11(1,.), addrows(1)
putdocx table tbl11(2,1) = ("Tax year"), font(Arial, 8)  border(top) border(bottom) halign(center) border(left)
putdocx table tbl11(2,2) = (" "), font(Arial, 8)  border(top) border(bottom) halign(center)
putdocx table tbl11(2,3) = ("Micro"),  font(Arial, 8)  border(left) border(right) border(top) border(bottom) halign(center)
putdocx table tbl11(2,4) = ("Small"), font(Arial, 8)  border(left) border(right) border(top) border(bottom) halign(center)
putdocx table tbl11(2,5) = ("Medium -large"), font(Arial, 8)  border(left) border(right) border(top) border(bottom) halign(center) 
local row = 2
foreach year in $yearlist{
	putdocx table tbl11(`row',.) , addrows(2)
	local ++row 
	putdocx table tbl11(`row', 1) = ("`year'") , border(left) border(top)  border(right) halign(center) font(Arial, 8)
	local ++row
	putdocx table tbl11(`row', 1) = (" ") , border(left) border(bottom) border(right)
    local --row 
	putdocx table tbl11(`row', 2) = ("SA parent") , border(left) border(top) border(bottom) border(right) font(Arial, 8)
	local ++row
	putdocx table tbl11(`row', 2) = ("Foreign parent") , border(left) border(top) border(bottom) border(right) font(Arial, 8)
	
	*Table values 
	count if ITR14_c_mne_type == 1 & c_type ==3 & taxyear ==`year' 
	local b_m = r(N)
	count if ITR14_c_mne_type == 1 & c_type ==4 & taxyear ==`year' 
	local b_s = r(N)
	count if ITR14_c_mne_type == 1 & c_type ==5 & taxyear ==`year' 
	local b_ml = r(N)
	count if ITR14_c_mne_type == 2 & c_type ==3 & taxyear ==`year' 
	local s_m = r(N)
	count if ITR14_c_mne_type == 2 & c_type ==4 & taxyear ==`year' 
	local s_s = r(N)
	count if ITR14_c_mne_type == 2 & c_type ==5 & taxyear ==`year' 
	local s_ml = r(N)
	
	local --row 
	putdocx table tbl11(`row',3) = ("`b_m'") , font(Arial, 8) halign(center)  nformat(%12.0gc) 
	putdocx table tbl11(`row',4) = ("`b_s'") , font(Arial, 8) halign(center) nformat(%12.0gc) 
	putdocx table tbl11(`row',5) = ("`b_ml'") , font(Arial, 8) halign(center) border(right) nformat(%12.0gc) 
	
	local ++row 
	putdocx table tbl11(`row',3) = ("`s_m'") , font(Arial, 8) halign(center) nformat(%12.0gc) 
	putdocx table tbl11(`row',4) = ("`s_s'") , font(Arial, 8) halign(center) nformat(%12.0gc) 
	putdocx table tbl11(`row',5) = ("`s_ml'") , font(Arial, 8) halign(center) border(right) nformat(%12.0gc) 
	
	
}

putdocx table tbl11(`row', .) , addrows(2)
local ++row 
putdocx table tbl11(`row', 1) = ("Notes: The company type classification is based on the gross income and total assets amounts reported by firms. Where there are less than 10 firms in a category the number is ‘masked‘ for data security reasons. Tax year 2018 is not fully populated due to delays in tax reporting; this results in the lower numbers in 2018 in this version of the panel. Number would likely be revised upward in future version of the panel") ,  font(Arial, 8) colspan(5) border(top) 
local ++row 
putdocx table tbl11(`row', 1) = ("Source: Authors’ illustration of the data in the CIT-IRP5 panel v4.0 (National Treasury and UNU-WIDER 2020)") , font(Arial, 8) 
putdocx table tbl11(1,. ) , addrows(1, before) 
putdocx table tbl11(1, 1) = ("Table C2: MNEs by Company type") ,  font(Arial, 8) colspan(5) 

putdocx pagebreak

*Table C3: FCFs by Company type
putdocx table tbl12 = (1,4) , border(all, nil) halign(center)
putdocx table tbl12(1,1) = (" ") , border(left) border(right) border(top) border(bottom) colspan(2)
putdocx table tbl12(1,2) = ("Company type"), font(Arial, 8)  border(left) border(right) border(top) border(bottom) colspan(3) halign(center)
putdocx table tbl12(1,.), addrows(1)
putdocx table tbl12(2,1) = ("Tax year"), font(Arial, 8)  border(top) border(bottom) halign(center) border(left)
putdocx table tbl12(2,2) = ("Micro"),  font(Arial, 8)  border(left) border(right) border(top) border(bottom) halign(center)
putdocx table tbl12(2,3) = ("Small"), font(Arial, 8)  border(left) border(right) border(top) border(bottom) halign(center)
putdocx table tbl12(2,4) = ("Medium -large"), font(Arial, 8)  border(left) border(right) border(top) border(bottom) halign(center) 
local row = 2
foreach year in $yearlist{
	putdocx table tbl12(`row',.) , addrows(2)
	
	*Table values 
	count if  ITR14_c_fcf == 1 & c_type ==3 & taxyear ==`year' 
	local b_m = r(N)
	count if  ITR14_c_fcf == 1 & c_type ==4 & taxyear ==`year' 
	local b_s = r(N)
	count if  ITR14_c_fcf == 1 & c_type ==5 & taxyear ==`year' 
	local b_ml = r(N)

	local ++row
	putdocx table tbl12(`row',1) = ("`year'") , font(Arial, 8) halign(center) border(left) 
	putdocx table tbl12(`row',2) = ("`b_m'") , font(Arial, 8) halign(center) nformat(%12.0gc) 
	putdocx table tbl12(`row',3) = ("`b_s'") , font(Arial, 8) halign(center) nformat(%12.0gc) 
	putdocx table tbl12(`row',4) = ("`b_ml'") , font(Arial, 8) halign(center) border(right) nformat(%12.0gc)
	

}

putdocx table tbl12(`row', .) , addrows(2)
local ++row 
putdocx table tbl12(`row', 1) = ("Notes: The company type classification is based on the gross income and total assets amounts reported by firms.Where there are less than 10 firms in a category the number is ‘masked‘ for data security reasons. Tax year 2018 is not fully populated due to delays in tax reporting; this results in the lower numbers in 2018 in this version of the panel. Number would likely be revised upward in future version of the panel") ,  font(Arial, 8) colspan(5) border(top) 
local ++row 
putdocx table tbl12(`row', 1) = ("Source: Authors’ illustration of the data in the CIT-IRP5 panel v4.0 (National Treasury and UNU-WIDER 2020).") , font(Arial, 8) 
putdocx table tbl12(1,. ) , addrows(1, before) 
putdocx table tbl12(1, 1) = ("Table C3: FCFs by Company type") ,  font(Arial, 8) colspan(5) 



*save final document 
putdocx save "$sadrs\Kilumelume et al. tables .docx", replace




